@@ -11,6 +11,8 @@ import websockets
 
 from opal_common.logger import logger, configure_logs
 from opal_common.middleware import configure_middleware
+from opal_common.config import opal_common_config
+from opal_common.security.sslcontext import get_custom_ssl_context
 from opal_client.config import PolicyStoreTypes, opal_client_config
 from opal_client.data.api import init_data_router
 from opal_client.data.updater import DataUpdater
@@ -54,26 +56,37 @@ class OpalClient:
         # Init policy updater
         self.policy_updater = policy_updater if policy_updater is not None else PolicyUpdater(policy_store=self.policy_store)
         # Data updating service
-        if data_updater is not None:
-            self.data_updater = data_updater
+        if opal_client_config.DATA_UPDATER_ENABLED:
+            if data_updater is not None:
+                self.data_updater = data_updater
+            else:
+                data_topics = data_topics if data_topics is not None else opal_client_config.DATA_TOPICS
+                self.data_updater = DataUpdater(policy_store=self.policy_store, data_topics=data_topics)
         else:
-            data_topics = data_topics if data_topics is not None else opal_client_config.DATA_TOPICS
-            self.data_updater = DataUpdater(policy_store=self.policy_store, data_topics=data_topics)
+            self.data_updater = None
 
         # Internal services
         # Policy store
         if self.policy_store_type == PolicyStoreTypes.OPA and inline_opa_enabled:
-            self.opa_runner = OpaRunner.setup_opa_runner(
-                options=inline_opa_options,
-                rehydration_callbacks=[
-                    # refetches policy code (e.g: rego) and static data from server
-                    functools.partial(self.policy_updater.update_policy, force_full_update=True),
-                    functools.partial(self.data_updater.get_base_policy_data, data_fetch_reason="policy store rehydration"),
-                ]
-            )
+            rehydration_callbacks = [
+                # refetches policy code (e.g: rego) and static data from server
+                functools.partial(self.policy_updater.update_policy, force_full_update=True),
+            ]
+
+            if self.data_updater:
+                rehydration_callbacks.append(
+                    functools.partial(self.data_updater.get_base_policy_data, data_fetch_reason="policy store rehydration")
+                )
+
+            self.opa_runner = OpaRunner.setup_opa_runner(options=inline_opa_options, rehydration_callbacks=rehydration_callbacks)
         else:
             self.opa_runner = False
 
+
+        custom_ssl_context = get_custom_ssl_context()
+        if opal_common_config.CLIENT_SELF_SIGNED_CERTIFICATES_ALLOWED and custom_ssl_context is not None:
+            logger.warning("OPAL client is configured to trust self-signed certificates")
+
         # init fastapi app
         self.app: FastAPI = self._init_fast_api_app()
 
@@ -184,7 +197,7 @@ class OpalClient:
             for task in asyncio.as_completed([self.launch_policy_updater(), self.launch_data_updater()]):
                 await task
         except websockets.exceptions.InvalidStatusCode as err:
-            logger.error("Failed to launch background task -- {err}", err=err)
+            logger.error("Failed to launch background task -- {err}", err=repr(err))
             self._trigger_shutdown()
 
     async def maybe_init_healthcheck_policy(self):
@@ -208,13 +221,13 @@ class OpalClient:
         try:
             healthcheck_policy_code = open(healthcheck_policy_path, 'r').read()
         except IOError as err:
-            logger.error("Critical: Cannot read healthcheck policy: {err}", err=err)
+            logger.error("Critical: Cannot read healthcheck policy: {err}", err=repr(err))
             raise
 
         try:
             await self.policy_store.init_healthcheck_policy(policy_id=healthcheck_policy_relpath, policy_code=healthcheck_policy_code)
         except aiohttp.ClientError as err:
-            logger.error("Failed to connect to OPA agent while init healthcheck policy -- {err}", err=err)
+            logger.error("Failed to connect to OPA agent while init healthcheck policy -- {err}", err=repr(err))
             raise
 
     def _trigger_shutdown(self):
