@@ -27,6 +27,7 @@ class OpalClientConfig(Confi):
     # opa client (policy store) configuration
     POLICY_STORE_TYPE = confi.enum("POLICY_STORE_TYPE", PolicyStoreTypes, PolicyStoreTypes.OPA)
     POLICY_STORE_URL = confi.str("POLICY_STORE_URL", f"http://localhost:8181/v1")
+    POLICY_STORE_AUTH_TOKEN = confi.str("POLICY_STORE_AUTH_TOKEN", None, description="the authentication (bearer) token OPAL client will use to authenticate against the policy store (i.e: OPA agent)")
     # create an instance of a policy store upon load
 
     def load_policy_store():
@@ -85,6 +86,11 @@ class OpalClientConfig(Confi):
                                           description="directories in policy repo we should subscribe to")
 
     # Data updater configuration --------------------------------------------------
+    DATA_UPDATER_ENABLED = confi.bool(
+        "DATA_UPDATER_ENABLED",
+        True,
+        description="If set to False, opal client will not listen to dynamic data updates. Dynamic data fetching will be completely disabled.")
+
     DATA_TOPICS = confi.list("DATA_TOPICS", ["policy_data"],
                              description="Data topics to subscribe to")
 
@@ -94,10 +100,10 @@ class OpalClientConfig(Confi):
     DEFAULT_DATA_URL = confi.str("DEFAULT_DATA_URL", "http://localhost:8000/policy-config",
                                  description="Default URL to fetch data from")
 
-    SHOULD_REPORT_ON_DATA_UPDATES = confi.bool("SEND_REPORTS_ON_DATA_UPDATES", False,
+    SHOULD_REPORT_ON_DATA_UPDATES = confi.bool("SHOULD_REPORT_ON_DATA_UPDATES", False,
                                               description="Should the client report on updates to callbacks defined in DEFAULT_UPDATE_CALLBACKS or within the given updates")
     DEFAULT_UPDATE_CALLBACK_CONFIG = confi.model(
-        "DEFAULT_UPDATE_CALLBACK_CONFIG", HttpFetcherConfig, {"method": "post"})
+        "DEFAULT_UPDATE_CALLBACK_CONFIG", HttpFetcherConfig, {"method": "post", "headers": {"content-type": "application/json"}, "process_data": False})
 
     DEFAULT_UPDATE_CALLBACKS = confi.model("DEFAULT_UPDATE_CALLBACKS", UpdateCallback, confi.delay(lambda SERVER_URL="": {
         "callbacks": [f"{SERVER_URL}/data/callback_report"]
