@@ -86,7 +86,8 @@ class OpaRunner:
     def command(self):
         opts = self._options.get_cli_options_dict()
         opts_string = ' '.join([f"{k}={v}" for k,v in opts.items()])
-        return f"opa run --server {opts_string}"
+        startup_files = self._options.get_opa_startup_files()
+        return f"opa run --server {opts_string} {startup_files}".strip()
 
     def _terminate_opa(self):
         logger.info("Stopping OPA")
@@ -109,7 +110,8 @@ class OpaRunner:
         self._process = await asyncio.create_subprocess_shell(
             self.command,
             stdout=asyncio.subprocess.PIPE,
-            stderr=asyncio.subprocess.PIPE
+            stderr=asyncio.subprocess.PIPE,
+            start_new_session=True,
         )
 
         # waits until the process is up, then runs a callback
